package com.liangguocheng.flutter_upgrade_plugin;

import android.app.Activity;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.graphics.Color;
import android.os.Environment;

import constacne.UiType;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import model.UiConfig;
import model.UpdateConfig;
import update.UpdateAppUtils;

/**
 * FlutterUpgradePlugin
 */
public class FlutterUpgradePlugin implements MethodCallHandler {
    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_upgrade_plugin");
        channel.setMethodCallHandler(new FlutterUpgradePlugin(registrar.activity()));
    }

    private Activity activity;

    public FlutterUpgradePlugin(Activity activity) {
        this.activity = activity;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case "getPlatformVersion":
                getPlatformVersion(call, result);
                break;
            case "getAppVersionName":
                getAppVersionName(call, result);
                break;
            case "showUpgradeDialog":
                showUpgradeDialog(call, result);
                break;
            default:
                result.notImplemented();
        }

    }

    /**
     * 显示升级更新对话框
     *
     * @param call
     * @param result
     */
    private void showUpgradeDialog(MethodCall call, Result result) {
        //最新版本名称
        String serverVersionName = call.argument("serverVersionName");
        //本地版本名称
        String localVersionName = getVersionName();
        if (localVersionName.compareTo(serverVersionName) >= 0) return;

        String title = call.argument("title");
        String description = call.argument("description");
        String apkDownLoadUrl = call.argument("apkDownLoadUrl");
        boolean force = call.argument("force");

        //更新对话框设置
        UiConfig uiConfig = new UiConfig();
        uiConfig.setUiType(UiType.CUSTOM);
        uiConfig.setCustomLayoutId(R.layout.view_update_dialog_custom);
        UpdateConfig updateConfig = new UpdateConfig();
        updateConfig.setForce(force);
        updateConfig.setAlwaysShowDownLoadDialog(true);
        updateConfig.setApkSaveName("app_" + System.currentTimeMillis());
        updateConfig.setServerVersionName(serverVersionName);
        updateConfig.setDebug(false);
        updateConfig.setShowDownloadingToast(false);
        updateConfig.setShowNotification(false);

        UpdateAppUtils
                .getInstance()
                .uiConfig(uiConfig)
                .updateConfig(updateConfig)
                .apkUrl(apkDownLoadUrl)
                .updateTitle(title)
                .updateContent(description)
                .update();
    }


    /**
     * 获取当前系统版本
     *
     * @param call
     * @param result
     */
    private void getPlatformVersion(MethodCall call, Result result) {
        result.success("Android " + android.os.Build.VERSION.RELEASE);
    }

    /**
     * 获取app版本名称
     *
     * @param call
     * @param result
     */
    private void getAppVersionName(MethodCall call, Result result) {
        result.success(getVersionName());
    }

    /**
     * 获取android版本名称
     *
     * @return
     */
    private String getVersionName() {
        PackageManager manager = activity.getPackageManager();
        String versionName = null;
        try {
            PackageInfo info = manager.getPackageInfo(activity.getPackageName(), 0);
            versionName = info.versionName;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return versionName;
    }
}
